{                                                                           }
{ File:       EchoC.dpr                                                     }
{ Function:   Program for batch and command files to output text in color.  }
{ Language:   Delphi for Win32                                              }
{ Author:     Rudy Velthuis                                                 }
{ Copyright:  (c) 2007 Rudy Velthuis                                        }
{ Disclaimer: This code is freeware. All rights are reserved.               }
{             This code is provided as is, expressly without a warranty     }
{             of any kind. You use it at your own risk.                     }
{                                                                           }
{             If you use this code, please credit me.                       }
{                                                                           }

program echoc;

{$APPTYPE CONSOLE}

uses
  Console;

procedure SetColorFromStr(const S: string; Foreground: Boolean);
var
  Color: Byte;
  I: Integer;
begin
  Color := 0;
  for I := 1 to Length(S) do
    if S[I] in ['0'..'9'] then
      Color := Color * 10 + Ord(S[I]) - Ord('0')
    else
      Break;
  if Foreground then
    TextColor(Color)
  else
    TextBackground(Color);
end;

procedure WriteStr(const S: string; Separator: Boolean);
var
  I: Integer;
begin
  for I := 1 to Length(S) do
    if S[I] = '^' then
      Write(#13#10)
    else
      Write(S[I]);
  if Separator then
    Write(' ');
end;

procedure Help;
const
  HelpText =
    #13#10 +
    'ECHO in Color, Copyright (c) 2007 by Rudy Velthuis.'#13#10 +
    #13#10 +
    'Usage: ECHOC backgnd foregnd "The text"'#13#10 +
    #13#10 +
    'Foreground and background colors are numbers 0..15.'#13#10 + 
    'A ^ in the text represents a newline.'#13#10;
begin
  Writeln(HelpText);
end;

var
  OldColor: Byte;
  I: Integer;

begin
  OldColor := Console.TextAttr;
  if ParamCount = 0 then
    Help;
  if ParamCount > 0 then
    SetColorFromStr(ParamStr(1), False);
  if ParamCount > 1 then
    SetColorFromStr(ParamStr(2), True);
  if ParamCount > 2 then
    for I := 3 to ParamCount do
      WriteStr(ParamStr(I), I < ParamCount);
  Console.TextBackground((OldColor and $F0) shr 4);
  Console.TextColor(OldColor and $0F);
end.
